-------------------------------------------------------------------------------
-- MrTrader 0.1
--
-- Lightweight addon to access profession information of alts.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader", true);

local Defaults = {
	factionrealm = {
		skills = {},
	}
}

-- List of tradeskills
-- Key: Spell ID
-- Value: true if this skill has a tradeskill link you can share
local TradeSkills = {
	[2259] = true, -- Alchemy
	[2018] = true, -- Blacksmithing
	[2250] = true, -- Cooking
	[7411] = true, -- Enchanting
	[4036] = true, -- Engineering
	[3273] = true, -- First Aid
	[45357] = true, -- Inscription
	[25229] = true, -- Jewelcrafting
	[2108] = true, -- Leatherworking
	[53428] = false, -- Runeforging
	[2656] = false, -- Smelting
	[3908] = true, -- Tailoring	
}

function MrTrader:Load()
	self.db = LibStub("AceDB-3.0"):New("MrTraderDB", Defaults, "Default");
end

function MrTrader:QuerySkills()
	local currentPlayer = UnitName("player");	
	local skillTable = {};
	local oldTable = {};
	local didGrabUpdate = true;
	
	if self.db.factionrealm.skills[currentPlayer] then
		oldTable = self.db.factionrealm.skills[currentPlayer];
	end
	
	for skillID, usesLink in pairs(TradeSkills) do
		skillName = GetSpellInfo(skillID);
		doesExist, tradeLink = GetSpellLink(skillName);
		
		if doesExist and tradeLink then
			skillTable[skillID] = tradeLink;
		elseif doesExist and oldTable[skillID] then
			skillTable[skillID] = oldTable[skillID];
			didGrabUpdate = false;
		elseif doesExist then
			skillTable[skillID] = false;
			if usesLink then
				didGrabUpdate = false;
			end
		end
	end
	
	if self:TableSize(skillTable) > 0 then
		self.db.factionrealm.skills[currentPlayer] = skillTable;
		return didGrabUpdate;
	else
		self.db.factionrealm.skills[currentPlayer] = nil;
		return true;
	end
end

function MrTrader:GetSkillTable()
	return self.db.factionrealm.skills;
end

function MrTrader:RemoveCharacter(name)
	self.db.factionrealm.skills[name] = nil;
end